package com.billpringle.utils.wrputils;

/**
 * Abstraction of a date object.
 * 
 * 
	 *   <table border="0" cellspacing="0" cellpadding="6" align="center"
  summary="Creative Commons license">
    <tr>
      <td><!-- Creative Commons License -->
      <a rel="license" href=
      "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
      "CC"><img alt="Creative Commons License" border="0" src=
      "http://creativecommons.org/images/public/somerights20.gif" /></a></td>

      <td><a rel="license" href=
      "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
      "CC"><img alt="Creative Commons License Symbols" border="0"
      src="cc_lic.gif" /></a> <!-- /Creative Commons License --></td>

      <td>Unless noted otherwise, all materials available for
      download from my site are copyrighted by Bill Pringle, and
      are licensed under a <a rel="license" href=
      "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
      "CC">Creative Commons License</a>.</td>
    </tr>
  </table>

 * 
 * 
 * @author Bill Pringle
 *
 */
public class WrpDate {
	/** list of month abbreviations */
	protected static final String[] months = {
		"Jan", "Feb", "Mar", "Apr", "May", "Jun", 
		"Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
	/** year value */
	protected int year;
	/** month of year */
	protected int month;
	/** day of month */
	protected int day;
	/** string representation of date */
	protected String str;
	
	/**
	 * Default constructor
	 * 
	 */
	public WrpDate()
	{
		
	}
	
	/**
	 * Constructor with a date string
	 * 
	 * @param s date string (DD Mon YYYY)
	 */
	public WrpDate(String s)
	{
		parseStr(s); // parse the string
	}

	/**
	 * Get month abbreviation for month number
	 * 
	 * @param MonthNumber month number (1-12)
	 * @return abbreviation for specified month
	 */
	public static String monthAbbr(int MonthNumber)
	{
		if (MonthNumber< 0 || MonthNumber > 12)
		{
			return null;
		}
		
		return months[MonthNumber];
	}
	
	/**
	 * Convert the  name of the month to a number
	 * 
	 * @param MonthAbbr month name or abbreviation
	 * @return the number of the month
	 */
	public static int MonthNumber(String MonthAbbr)
	{
		String m;
		for (int i=0; i<months.length; i++)
		{ // look for match of month name
			m = months[i];
			if (m.equals(MonthAbbr)) return i+1;
		}
		return 0;
	}
	
	/**
	 * Parse the input string and convert to a date
	 * 
	 * @param s date string in format DD Mon YYYY
	 */
	private void parseStr(String s) {
		if (s==null) return; // bad parm - ignore it
		
		String[] flds = s.split(" ");
		if (flds.length != 3) return; // bad date string
		
		/* convert month to number */
		for (int i=0; i<months.length; i++)
		{
			String m = months[i]; // get this month name
			if (s.equals(m))
			{
				month=i+1;
				break;
			}
		}
		if (month==0) return; // invalid month
		
		day = Integer.parseInt(flds[0]);
		year = Integer.parseInt(flds[2]);
	}

	/**
	 * Get the year
	 * 
	 * @return the year
	 */
	public int getYear() {
		return year;
	}

	/**
	 * Set the year
	 * 
	 * @param year the year to set
	 */
	public void setYear(int year) {
		this.year = year;
	}

	/**
	 * Get the month
	 * 
	 * @return the month
	 */
	public int getMonth() {
		return month;
	}

	/**
	 * Set the month
	 * 
	 * @param month the month to set
	 */
	public void setMonth(int month) {
		this.month = month;
	}

	/**
	 * Get the day
	 * 
	 * @return the day
	 */
	public int getDay() {
		return day;
	}

	/**
	 * Set the day
	 * 
	 * @param day the day to set
	 */
	public void setDay(int day) {
		this.day = day;
	}

	/**
	 * Output date in string format
	 * 
	 */
	public String toString()
	{
		return str;
	}
	
}
