package com.billpringle.utils.wrputils;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;

/**
 * This class provides the ability to perform a readLine operation
 * for a Java console application.
 * </p>
 * 
 * 
  <table border="0" cellspacing="0" cellpadding="6" align="center"
  summary="Creative Commons license">
    <tr>
      <td><!-- Creative Commons License -->
      <a rel="license" href=
      "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
      "CC"><img alt="Creative Commons License" border="0" src=
      "http://creativecommons.org/images/public/somerights20.gif" /></a></td>

      <td><a rel="license" href=
      "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
      "CC"><img alt="Creative Commons License Symbols" border="0"
      src="cc_lic.gif" /></a> <!-- /Creative Commons License --></td>

      <td>Unless noted otherwise, all materials available for
      download from my site are copyrighted by Bill Pringle, and
      are licensed under a <a rel="license" href=
      "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
      "CC">Creative Commons License</a>.</td>
    </tr>
  </table>
 * 
 * @author Bill Pringle
 */
public class WrpKeyboard {
	
	/**
	 * maps to System.in, the user's keyboard
	 */
	private BufferedReader kbd=null;

	/**
	 * Default (and only) constructor.
	 * </p><p>
	 * This method opens the <i>System.in</i> input stream
	 * as a buffered reader, allowing the user to
	 * perform a readLine operation on the keyboard.
	 * 
	 */
	public WrpKeyboard()
	{
		// open the input stream as a buffered input stream
        InputStreamReader rdr = new InputStreamReader(System.in);
		// map to a buffered reader
        kbd = new BufferedReader(rdr);
	}
	
	/**
	 * Read a line from the user's keyboard.
	 * Since <a href="#kbd">kbd</a> is a buffered reader,
	 * it can accept the <i>readLine()</i> method. 
	 * 
	 * @return the line from the user
	 * @throws IOException
	 */
	public String readLine() throws IOException
	{
		String s = kbd.readLine(); // get the next line from the user
		return s; // return user's response
	}
	
	/**
	 * Return the buffered reader.
	 * </p><p>
	 * This method can be used to obtain the buffered reader.
	 * The client can then perform whatever operations are desired.
	 * 
	 * @return the buffered reader
	 */
	public BufferedReader getBufferedReader() { return kbd; }

	/**
	 * Test driver for the class.
	 * This method is mainly used for testing purposes.
	 * 
	 * @param args not used
	 */
	public static void main(String[] args)
	{
		WrpKeyboard kbd = new WrpKeyboard(); // create object
		
		try
		{ // loop reading lines from the user
			System.out.println("Enter lines, or ENTER to quit");
			while (true)
			{ // loop reading lines
				System.out.println("Enter a line: ");
				String s = kbd.readLine(); // get response
				System.out.println("Line read [" + s + "]");
				if (s.length()==0) break; // if empty line, quit
			}
		} catch (IOException e)
		{ // exception
			System.err.println("I/O Exception. e=" + e);
			e.printStackTrace();
		}
	}
}
