package com.billpringle.utils.wrputils;

import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.util.Vector;

/**
 * This class encapsulates a ResultSet.
 * The class can be used to build a JTable for the record set.
 * The class contains a Vector of type
 * {@link com.billpringle.utils.wrputils.WrpResultSetVector}.
 * 
 * 
 *   <table border="0" cellspacing="0" cellpadding="6" align="center"
summary="Creative Commons license">
<tr>
  <td><!-- Creative Commons License -->
  <a rel="license" href=
  "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
  "CC"><img alt="Creative Commons License" border="0" src=
  "http://creativecommons.org/images/public/somerights20.gif" /></a></td>

  <td><a rel="license" href=
  "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
  "CC"><img alt="Creative Commons License Symbols" border="0"
  src="cc_lic.gif" /></a> <!-- /Creative Commons License --></td>

  <td>Unless noted otherwise, all materials available for
  download from my site are copyrighted by Bill Pringle, and
  are licensed under a <a rel="license" href=
  "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
  "CC">Creative Commons License</a>.</td>
</tr>
</table>
 * 
 * @author Bill Pringle
 *
 */
public class WrpResultSetVector
{
	/** result set */
	public ResultSet resultSet;
	/** names of columns */
	public String[] colNames;
	/** names of column types */
	public String[] colTypes;
	/** columns to display in scroll view */
	public int[] colScroll;
	/** rows of result set */
	public Vector<WrpResultSetRow> rows;
	
	/**
	 * Constructor for result set.
	 * This is the normal constructor for this class.
	 * It will build column names and rows from the result set.
	 * 
	 * @param rs the ResultSet to encapsulate
	 * @throws SQLException
	 */
	public WrpResultSetVector(ResultSet rs) throws SQLException
	{
		resultSet = rs; // save result set
		buildColNames(); // get column names and build string array
		setColScroll(null); // default is to view all columns in scroll
		buildRows(); // build the data rows
	}

	/**
	 * Build a String array with column names.
	 * 
	 * @throws SQLException
	 */
	private void buildColNames() throws SQLException
	{
		Vector<String> cnames = new Vector<String>(); // work vector
		Vector<String> ctypes = new Vector<String>(); // work vector
		
		ResultSetMetaData md = resultSet.getMetaData();
		int ncols = md.getColumnCount(); //  number of columns

		// loop through columns and get names
		for (int i=1; i<=ncols; i++)
		{
			String s = md.getColumnName(i);
			cnames.add(s); // add column name
			String stype = md.getColumnTypeName(i).toLowerCase();
			ctypes.add(stype);
		}
		colNames = new String[ncols]; // build string array
		cnames.toArray(colNames); // store in column names array
		colTypes = new String[ncols]; // build string array for types
		ctypes.toArray(colTypes); // store in column types array
	}

	/**
	 * Build Vector of row elements
	 * @throws SQLException 
	 * 
	 */
	private void buildRows() throws SQLException
	{
		rows = new Vector<WrpResultSetRow>(); // create vector
		
		// loop through result set and create an object for each row
		resultSet.first();
		do
		{
			WrpResultSetRow row = new WrpResultSetRow(this);
			rows.add(row);
		} while (resultSet.next());

	}
	
	/**
	 * Get the corresponding row from the result set
	 * 
	 * @param ndx index of row
	 * @return the requested row
	 */
	public WrpResultSetRow getRow(int ndx)
	{
		WrpResultSetRow row = null;
		
		if (ndx >= 0 || ndx < rows.size())
		{
			row = rows.get(ndx);
		}
		return row;
	}

	/**
	 * @return the resultSet
	 */
	public ResultSet getResultSet()
	{
		return resultSet;
	}

	/**
	 * @param resultSet the resultSet to set
	 */
	public void setResultSet(ResultSet resultSet)
	{
		this.resultSet = resultSet;
	}

	/**
	 * @return the colNames
	 */
	public String[] getColNames()
	{
		return colNames;
	}

	/**
	 * @param colNames the colNames to set
	 */
	public void setColNames(String[] colNames)
	{
		this.colNames = colNames;
	}

	/**
	 * @return the colTypes
	 */
	public String[] getColTypes()
	{
		return colTypes;
	}

	/**
	 * @param colTypes the colTypes to set
	 */
	public void setColTypes(String[] colTypes)
	{
		this.colTypes = colTypes;
	}

	/**
	 * @return the colScroll
	 */
	public int[] getColScroll()
	{
		return colScroll;
	}

	/**
	 * @param colScroll the colScroll to set
	 */
	public void setColScroll(int[] colScroll)
	{
		this.colScroll = colScroll;
	}

	/**
	 * @return the rows
	 */
	public Vector<WrpResultSetRow> getRows()
	{
		return rows;
	}

	/**
	 * @param rows the rows to set
	 */
	public void setRows(Vector<WrpResultSetRow> rows)
	{
		this.rows = rows;
	}

}
