package com.billpringle.utils.wrputils;

import java.io.IOException;

/**
 * This class can be used to determine if a string 
 * is a valid USPS state abbreviation.
 * 
 * Validation can be done using a static routine:
 * <dl>
 * <dd><code>WrpState.isState(abbr);</code></dd>
 * </dl>
 *
 *
  <table border="0" cellspacing="0" cellpadding="6" align="center"
  summary="Creative Commons license">
    <tr>
      <td><!-- Creative Commons License -->
      <a rel="license" href=
      "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
      "CC"><img alt="Creative Commons License" border="0" src=
      "http://creativecommons.org/images/public/somerights20.gif" /></a></td>

      <td><a rel="license" href=
      "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
      "CC"><img alt="Creative Commons License Symbols" border="0"
      src="cc_lic.gif" /></a> <!-- /Creative Commons License --></td>

      <td>Unless noted otherwise, all materials available for
      download from my site are copyrighted by Bill Pringle, and
      are licensed under a <a rel="license" href=
      "http://creativecommons.org/licenses/by-nc-sa/2.0/" target=
      "CC">Creative Commons License</a>.</td>
    </tr>
  </table>
  
 * @author Bill Pringle
 *
 */
public class WrpState {
	/** serial version UID */
	final static long serialVersionUID = 1;

	/**
	 * List of US State abbreviations from USPS web site.
	 */
	static final public String[] states = { 
		/* US States and territories */
		"AL", "AK", "AZ", "AR", "CA", "CO", "CT", "DE","FL", "GA", 
		"HI", "ID", "IL", "IN", "IA", "KS", "KY", "LA", "ME", "MD", 
		"MA", "MI", "MN", "MS", "MO", "MT", "NE", "NV", "NH", "NJ", 
		"NM", "NY", "NC", "ND", "OH", "OK", "OR", "PA", "RI", "SC", 
		"SD", "TN", "TX", "UT", "VT", "VA", "WA", "WV", "WI", "WY",
		/* US territories */
		"DC", "AS", "FM", "GU", "MH", "MP", "PW", "PR", "VI", 
		/* armed forces */
		"AA", "AE", "AP"
		};

	/**
	 * Default constructor
	 * 
	 * Since validation routine is static, this routine isn't really needed
	 * 
	 */
	public WrpState()
	{
		
	}

	/**
	 * Routine to validate state abbreviation.
	 * 
	 * @param abbr abbreviation to check
	 * @return True if valid abbreviation
	 * 
	 */
	public static Boolean isState(String abbr)
	{
		String s = abbr.toUpperCase();
		for (int i=0; i<states.length; i++)
		{
			if (s.equals(states[i])) return true;
		}
		return false;
	}
	
	/**
	 * Test driver for class
	 * 
	 * @param args not used
	 * 
	 */
	public static void main(String[] args) {
		WrpKeyboard kb = new WrpKeyboard(); // implements readLine for System.in
		
		// loop getting abbreviations and validating them
		while (true)
		{ // loop getting abbreviations from user
			try
			{
				// prompt user for abbreviation
				System.out.print("Enter state abbreviation, or ENTER to quit: ");
				String st = kb.readLine(); // get abbreviation
				if (st.length()==0) break; // empty response means quit
				if (WrpState.isState(st))
				{ // valid abbreviation
					System.out.println(st + " is a valid state abbreviation");
				}
				else
				{ // invalid abbreviation
					System.out.println("*** [" + st + "] not a valid state abbreviation");
				}
			} catch (IOException e)
			{ // should never happen
				System.err.println("IO Error while reading keyboard [" + e.getMessage() + "]");
				e.printStackTrace();
			}
		}
		System.out.println("Thanks for using WrpState!"); // say good-bye
		System.exit(0); // terminate program
	}

}
